==> qtjambi-sensors-6.4.0-sources.jar: io/qt/sensors/QHumiditySensor.java <==
package io.qt.sensors;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qhumiditysensor.html">QHumiditySensor</a></p>
 */
public class QHumiditySensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHumiditySensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QHumiditySensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QHumiditySensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhumiditysensor.html#QHumiditySensor">QHumiditySensor::QHumiditySensor(QObject*)</a></p>
     */
    public QHumiditySensor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QHumiditySensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::reading()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.sensors.QHumidityReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.sensors.QHumidityReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHumiditySensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QHumiditySensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QHumiditySensor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.5.2-sources.jar: io/qt/sensors/QHumiditySensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qhumiditysensor.html">QHumiditySensor</a></code></p>
 */
public class QHumiditySensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHumiditySensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QHumiditySensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QHumiditySensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhumiditysensor.html#QHumiditySensor">QHumiditySensor::<wbr>QHumiditySensor(QObject*)</a></code></p>
     */
    public QHumiditySensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QHumiditySensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QHumidityReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QHumidityReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QHumiditySensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QHumiditySensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QHumiditySensor instance, QDeclarativeConstructor constructor);
    
}
